Module shared_singleton
spsc_
ringbuf_
core
0.1.0
Module shared_
singleton
Module Items
Structs
Enums
In crate spsc_
ringbuf_
core
spsc_ringbuf_core
Module
shared_
singleton
Structs

Shared
Singleton
Single producer Single consumer Shared Singleton Note that different from RefCell, the shared singleton cannot be read until written by the producer
Enums

ErrCode